@@ -304,7 +304,7 @@ private:
   Lum::Model::StringTableRef         model;
   Lum::Model::ActionRef              okAction;
   Lum::Model::StringRef              nameModel;
-  Lum::Model::SizeTRef               typeModel;
+  Lum::Model::ULongRef               typeModel;
   DataEntryModelRef                  dataModel;
   Lum::Model::SingleLineSelectionRef selectionModel;
   bool                               success;
@@ -314,7 +314,7 @@ public:
   : model(new Lum::Model::StringTable()),
     okAction(new Lum::Model::Action),
     nameModel(new Lum::Model::String),
-    typeModel(new Lum::Model::SizeT),
+    typeModel(new Lum::Model::ULong),
     dataModel(new DataEntryModel(new DataEntryComparator())),
     selectionModel(new Lum::Model::SingleLineSelection()),
     success(false)
