@@ -26,7 +26,7 @@ namespace Views {
     Lum::Model::StringRef   description;
     Lum::Model::CalendarRef startDate;
     Lum::Model::CalendarRef endDate;
-    Lum::Model::SizeTRef    repeat;
+    Lum::Model::ULongRef    repeat;
     Lum::Model::CalendarRef repeatEndDate;
     Lum::Model::StringRef   repeatInterval;
     Lum::Model::BooleanRef  wholeDay;
